@@ -1,5 +1,5 @@
 """
-    InceptionResNetV2, implemented in PyTorch.
+    InceptionResNetV2 for ImageNet-1K, implemented in PyTorch.
     Original paper: 'Inception-v4, Inception-ResNet and the Impact of Residual Connections on Learning,'
     https://arxiv.org/abs/1602.07261.
 """
@@ -514,17 +514,17 @@ class InceptionResNetV2(nn.Module):
                     stage.add_module("unit{}".format(j + 1), unit())
             self.features.add_module("stage{}".format(i + 1), stage)
 
-        self.features.add_module('final_conv', incept_conv1x1(
+        self.features.add_module("final_conv", incept_conv1x1(
             in_channels=2080,
             out_channels=1536))
-        self.features.add_module('final_pool', nn.AvgPool2d(
+        self.features.add_module("final_pool", nn.AvgPool2d(
             kernel_size=8,
             stride=1))
 
         self.output = nn.Sequential()
         if dropout_rate > 0.0:
-            self.output.add_module('dropout', nn.Dropout(p=dropout_rate))
-        self.output.add_module('fc', nn.Linear(
+            self.output.add_module("dropout", nn.Dropout(p=dropout_rate))
+        self.output.add_module("fc", nn.Linear(
             in_features=1536,
             out_features=num_classes))
 
@@ -546,7 +546,7 @@ class InceptionResNetV2(nn.Module):
 
 def get_inceptionresnetv2(model_name=None,
                           pretrained=False,
-                          root=os.path.join('~', '.torch', 'models'),
+                          root=os.path.join("~", ".torch", "models"),
                           **kwargs):
     """
     Create InceptionResNetV2 model with specific parameters.
@@ -601,7 +601,6 @@ def _calc_width(net):
 
 def _test():
     import torch
-    from torch.autograd import Variable
 
     pretrained = False
 
@@ -619,7 +618,7 @@ def _test():
         print("m={}, {}".format(model.__name__, weight_count))
         assert (model != inceptionresnetv2 or weight_count == 55843464)
 
-        x = Variable(torch.randn(1, 3, 299, 299))
+        x = torch.randn(1, 3, 299, 299)
         y = net(x)
         y.sum().backward()
         assert (tuple(y.size()) == (1, 1000))
